package com.hs.api.mapper;

import com.hs.api.model.SysMenu;
import com.hs.api.model.respmodel.SysMenuList;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface SysMenuMapper {
    int deleteByPrimaryKey(Long id);

    int insert(SysMenu record);

    SysMenu selectByPrimaryKey(Long id);

    List<SysMenu> selectAll();

    int updateByPrimaryKey(SysMenu record);

    List<SysMenuList> selectMenuByUser(@Param("userId") Long userId);

    List<SysMenuList> selectMenuByType(@Param("menuType") Integer menuType);
}